==> wechat-facade-1.0.0-sources.jar: com/bizvane/wechatfacade/models/vo/UserAuthorizationGetUserInfoResponseVO.java <==
package com.bizvane.wechatfacade.models.vo;

import java.io.Serializable;

import io.swagger.annotations.ApiModelProperty;

public class UserAuthorizationGetUserInfoResponseVO implements Serializable {

  /**
   * 
   */
  private static final long serialVersionUID = 1L;
  
  @ApiModelProperty(value="品牌id", name="sysBrandId")
  private Long sysBrandId;
  
  @ApiModelProperty(value="appid", name="appid")
  private String appid;
  
  @ApiModelProperty(value="关联appid", name="relationAppid")
  private String relationAppid;
  
  @ApiModelProperty(value="会员卡号", name="openId")
  private String memberCode;
  
  @ApiModelProperty(value="微信openId", name="openId")
  private String openId;
  
  @ApiModelProperty(value="微信unionId", name="unionId")
  private String unionId;

  public String getMemberCode() {
    return memberCode;
  }

  public void setMemberCode(String memberCode) {
    this.memberCode = memberCode;
  }

  public String getOpenId() {
    return openId;
  }

  public void setOpenId(String openId) {
    this.openId = openId;
  }

  public String getUnionId() {
    return unionId;
  }

  public void setUnionId(String unionId) {
    this.unionId = unionId;
  }

  public Long getSysBrandId() {
    return sysBrandId;
  }

  public void setSysBrandId(Long sysBrandId) {
    this.sysBrandId = sysBrandId;
  }

  public String getAppid() {
    return appid;
  }

  public void setAppid(String appid) {
    this.appid = appid;
  }

  public String getRelationAppid() {
    return relationAppid;
  }

  public void setRelationAppid(String relationAppid) {
    this.relationAppid = relationAppid;
  }
  
  
  
  
  
  

}

==> wechat-facade-1.0.2-20190628.061622-37-sources.jar: com/bizvane/wechatfacade/models/vo/UserAuthorizationGetUserInfoResponseVO.java <==
package com.bizvane.wechatfacade.models.vo;

import java.io.Serializable;

import io.swagger.annotations.ApiModelProperty;

public class UserAuthorizationGetUserInfoResponseVO implements Serializable {

  /**
   * 
   */
  private static final long serialVersionUID = 1L;
  
  @ApiModelProperty(value="品牌id", name="sysBrandId")
  private Long sysBrandId;

  @ApiModelProperty(value="品牌id", name="sysBrandId")
  private Long sysCompanyId;

  @ApiModelProperty(value="appid", name="appid")
  private String appid;
  
  @ApiModelProperty(value="关联appid", name="relationAppid")
  private String relationAppid;
  
  @ApiModelProperty(value="会员卡号", name="openId")
  private String memberCode;
  
  @ApiModelProperty(value="微信openId", name="openId")
  private String openId;
  
  @ApiModelProperty(value="微信unionId", name="unionId")
  private String unionId;

  public String getMemberCode() {
    return memberCode;
  }

  public void setMemberCode(String memberCode) {
    this.memberCode = memberCode;
  }

  public String getOpenId() {
    return openId;
  }

  public void setOpenId(String openId) {
    this.openId = openId;
  }

  public String getUnionId() {
    return unionId;
  }

  public void setUnionId(String unionId) {
    this.unionId = unionId;
  }

  public Long getSysBrandId() {
    return sysBrandId;
  }

  public void setSysBrandId(Long sysBrandId) {
    this.sysBrandId = sysBrandId;
  }

  public String getAppid() {
    return appid;
  }

  public void setAppid(String appid) {
    this.appid = appid;
  }

  public String getRelationAppid() {
    return relationAppid;
  }

  public void setRelationAppid(String relationAppid) {
    this.relationAppid = relationAppid;
  }

  public Long getSysCompanyId() {
    return sysCompanyId;
  }

  public void setSysCompanyId(Long sysCompanyId) {
    this.sysCompanyId = sysCompanyId;
  }

}
